Changelog
---------

0.2 (2016-08-11)
++++++++++++++++++

* Added object schema inheritance: objects can inherit fields from other objects.
* Added support for customizing error messages in Fields.
* Changed ConstantField to validate value to be the same on load.
* Added OneOf type to express polymorphic types or type alternatives.

0.1 (2016-07-28)
++++++++++++++++

* Initial release.
